import pandas as pd
import matplotlib.pyplot as plt
import seaborn as sns

# Set the plotting style
sns.set_style("whitegrid")


# Load the training data
train_data = pd.read_csv("train.csv")

# Load the test data
test_data = pd.read_csv("test.csv")

# Combine the two datasets
data = pd.concat([train_data, test_data], axis=0)

# Display the first five rows of the dataset
print(data.head())

# Display the summary statistics of the dataset
print(data.describe())

# Display the data types of the columns
print(data.dtypes)

# Check for missing values
print(data.isnull().sum())

data = data.reset_index(drop=True)

numeric_data = data.select_dtypes(include=["int64", "float64"])
correlation_matrix = numeric_data.corr()

# Bar plot of the number of passengers by sex
sns.countplot(x="Sex", data=data)
plt.title("Number of Passengers by Sex")
plt.show()

# Box plot of the age of passengers by sex
sns.boxplot(x="Sex", y="Age", data=data)
plt.title("Age of Passengers by Sex")
plt.show()

# Histogram of the age of passengers
sns.histplot(data["Age"], bins=20)
plt.title("Age of Passengers")
plt.show()

# Scatter plot of the fare paid by passengers vs. their age
sns.scatterplot(x="Age", y="Fare", data=data)
plt.title("Fare Paid by Passengers vs. Age")
plt.show()

# Pie chart of the passenger class
class_counts = data["Pclass"].value_counts()
plt.pie(class_counts, labels=class_counts.index, autopct="%1.1f%%")
plt.axis("equal")
plt.title("Passenger Class")
plt.show()

# Heatmap of the correlation between numerical variables
correlation_matrix = numeric_data.corr()
sns.heatmap(correlation_matrix, annot=True, cmap="coolwarm")
plt.title("Correlation Matrix")
plt.show()


